/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#ifndef _NO_PROTO
void            SetView (int ViewType);
void 		create_Ortho_window(void);
void 		create_Stereo_window(void);
void 		create_Perspective_window(void);
#else
void            SetView ();
void 		create_Ortho_window();
void 		create_Stereo_window();
void 		create_Perspective_window();
#endif
